@@ -69,7 +69,7 @@ public:
 };
 
 class KWidgetGuard : public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 protected:
 	KWidget_impl *impl;
