@@ -83,7 +83,7 @@ public:
 		menu = new TDEPopupMenu( 0 );
 		_showSV = _artsactions->actionScopeView();
 		_showSV->plug( menu );
-		_showSVinline = new TDEAction( i18n( "Toggle &Inline FFT Scope" ), "artscontrol", TDEShortcut(), this, TQT_SLOT( SVinline() ), this );
+		_showSVinline = new TDEAction( i18n( "Toggle &Inline FFT Scope" ), "artscontrol", TDEShortcut(), this, TQ_SLOT( SVinline() ), this );
 		_showSVinline->plug( menu );
 		_showAM = _artsactions->actionAudioManager();
 		_showAM->plug( menu );
@@ -97,12 +97,12 @@ public:
 		_showMediaTypes->plug( menu );
 		menu->insertSeparator();
 		menu->insertItem( i18n( "VU-Style" ), _artsactions->stylemenu() );
-		connect( _artsactions, TQT_SIGNAL( styleNormal() ), this, TQT_SLOT( styleNormalBars() ) );
-		connect( _artsactions, TQT_SIGNAL( styleFire() ), this, TQT_SLOT( styleFireBars() ) );
-		connect( _artsactions, TQT_SIGNAL( styleLine() ), this, TQT_SLOT( styleLineBars() ) );
-		connect( _artsactions, TQT_SIGNAL( styleLED() ), this, TQT_SLOT( styleLEDs() ) );
-		connect( _artsactions, TQT_SIGNAL( styleAnalog() ), this, TQT_SLOT( styleAnalog() ) );
-		connect( _artsactions, TQT_SIGNAL( styleSmall() ), this, TQT_SLOT( styleSmall() ) );
+		connect( _artsactions, TQ_SIGNAL( styleNormal() ), this, TQ_SLOT( styleNormalBars() ) );
+		connect( _artsactions, TQ_SIGNAL( styleFire() ), this, TQ_SLOT( styleFireBars() ) );
+		connect( _artsactions, TQ_SIGNAL( styleLine() ), this, TQ_SLOT( styleLineBars() ) );
+		connect( _artsactions, TQ_SIGNAL( styleLED() ), this, TQ_SLOT( styleLEDs() ) );
+		connect( _artsactions, TQ_SIGNAL( styleAnalog() ), this, TQ_SLOT( styleAnalog() ) );
+		connect( _artsactions, TQ_SIGNAL( styleSmall() ), this, TQ_SLOT( styleSmall() ) );
 	}
 	~ArtsControlAppletPrivate() {
 		if ( svinline ) SVinline();
