@@ -120,36 +120,36 @@ PlaylistBox::PlaylistBox(TQWidget *parent, TQWidgetStack *playlistStack,
     raise(CollectionList::instance());
 
     viewModeAction->plug(m_contextMenu);
-    connect(viewModeAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotSetViewMode(int)));
+    connect(viewModeAction, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotSetViewMode(int)));
 
-    connect(this, TQT_SIGNAL(selectionChanged()),
-	    this, TQT_SLOT(slotPlaylistChanged()));
+    connect(this, TQ_SIGNAL(selectionChanged()),
+	    this, TQ_SLOT(slotPlaylistChanged()));
 
-    connect(this, TQT_SIGNAL(doubleClicked(TQListViewItem *)),
-	    this, TQT_SLOT(slotDoubleClicked()));
+    connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem *)),
+	    this, TQ_SLOT(slotDoubleClicked()));
 
-    connect(this, TQT_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
-	    this, TQT_SLOT(slotShowContextMenu(TQListViewItem *, const TQPoint &, int)));
+    connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
+	    this, TQ_SLOT(slotShowContextMenu(TQListViewItem *, const TQPoint &, int)));
 
     TagTransactionManager *tagManager = TagTransactionManager::instance();
-    connect(tagManager, TQT_SIGNAL(signalAboutToModifyTags()), TQT_SLOT(slotFreezePlaylists()));
-    connect(tagManager, TQT_SIGNAL(signalDoneModifyingTags()), TQT_SLOT(slotUnfreezePlaylists()));
+    connect(tagManager, TQ_SIGNAL(signalAboutToModifyTags()), TQ_SLOT(slotFreezePlaylists()));
+    connect(tagManager, TQ_SIGNAL(signalDoneModifyingTags()), TQ_SLOT(slotUnfreezePlaylists()));
 
     setupUpcomingPlaylist();
 
-    connect(CollectionList::instance(), TQT_SIGNAL(signalNewTag(const TQString &, unsigned)),
-            this, TQT_SLOT(slotAddItem(const TQString &, unsigned)));
-    connect(CollectionList::instance(), TQT_SIGNAL(signalRemovedTag(const TQString &, unsigned)),
-            this, TQT_SLOT(slotRemoveItem(const TQString &, unsigned)));
+    connect(CollectionList::instance(), TQ_SIGNAL(signalNewTag(const TQString &, unsigned)),
+            this, TQ_SLOT(slotAddItem(const TQString &, unsigned)));
+    connect(CollectionList::instance(), TQ_SIGNAL(signalRemovedTag(const TQString &, unsigned)),
+            this, TQ_SLOT(slotRemoveItem(const TQString &, unsigned)));
 
-    TQTimer::singleShot(0, object(), TQT_SLOT(slotScanFolders()));
+    TQTimer::singleShot(0, object(), TQ_SLOT(slotScanFolders()));
     enableDirWatch(true);
 
     // Auto-save playlists after 10 minutes
-    TQTimer::singleShot(600000, this, TQT_SLOT(slotSavePlaylists()));
+    TQTimer::singleShot(600000, this, TQ_SLOT(slotSavePlaylists()));
 
     m_showTimer = new TQTimer(this);
-    connect(m_showTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotShowDropTarget()));
+    connect(m_showTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotShowDropTarget()));
 }
 
 PlaylistBox::~PlaylistBox()
@@ -232,8 +232,8 @@ void PlaylistBox::setupPlaylist(Playlist *playlist, const TQString &iconName)
 
 void PlaylistBox::setupPlaylist(Playlist *playlist, const TQString &iconName, Item *parentItem)
 {
-    connect(playlist, TQT_SIGNAL(signalPlaylistItemsDropped(Playlist *)),
-	    TQT_SLOT(slotPlaylistItemsDropped(Playlist *)));
+    connect(playlist, TQ_SIGNAL(signalPlaylistItemsDropped(Playlist *)),
+	    TQ_SLOT(slotPlaylistItemsDropped(Playlist *)));
 
     PlaylistCollection::setupPlaylist(playlist, iconName);
 
@@ -375,7 +375,7 @@ void PlaylistBox::slotSavePlaylists()
     Cache::savePlaylists(l);
     CoverManager::saveCovers();
 
-    TQTimer::singleShot(600000, this, TQT_SLOT(slotSavePlaylists()));
+    TQTimer::singleShot(600000, this, TQ_SLOT(slotSavePlaylists()));
 }
 
 void PlaylistBox::slotShowDropTarget()
@@ -524,14 +524,14 @@ void PlaylistBox::contentsDragLeaveEvent(TQDragLeaveEvent *e)
 
 void PlaylistBox::contentsMousePressEvent(TQMouseEvent *e)
 {
-    if(e->button() == Qt::LeftButton)
+    if(e->button() == TQt::LeftButton)
 	m_doingMultiSelect = true;
     TDEListView::contentsMousePressEvent(e);
 }
 
 void PlaylistBox::contentsMouseReleaseEvent(TQMouseEvent *e)
 {
-    if(e->button() == Qt::LeftButton) {
+    if(e->button() == TQt::LeftButton) {
 	m_doingMultiSelect = false;
 	slotPlaylistChanged();
     }
@@ -770,11 +770,11 @@ void PlaylistBox::Item::init()
     list->addNameToDict(m_text);
 
     if(m_playlist) {
-	connect(m_playlist, TQT_SIGNAL(signalNameChanged(const TQString &)),
-		this, TQT_SLOT(slotSetName(const TQString &)));
-	connect(m_playlist, TQT_SIGNAL(destroyed()), this, TQT_SLOT(deleteLater()));
-	connect(m_playlist, TQT_SIGNAL(signalEnableDirWatch(bool)),
-	        list->object(), TQT_SLOT(slotEnableDirWatch(bool)));
+	connect(m_playlist, TQ_SIGNAL(signalNameChanged(const TQString &)),
+		this, TQ_SLOT(slotSetName(const TQString &)));
+	connect(m_playlist, TQ_SIGNAL(destroyed()), this, TQ_SLOT(deleteLater()));
+	connect(m_playlist, TQ_SIGNAL(signalEnableDirWatch(bool)),
+	        list->object(), TQ_SLOT(slotEnableDirWatch(bool)));
     }
 
     if(m_playlist == CollectionList::instance()) {
